<?php

require_once 'constants.php';
require 'vendor/autoload.php'; // Include GuzzleHTTP

use GuzzleHttp\Client;

$appId = APP_ID;
$appSecret = APP_SECRET;
$redirectUri = 'https://demo.imageonline.in/irctc-news-feed/fb-oauth-response.php'; // e.g., 'https://yourwebsite.com/fb-callback.php';
$permissions = 'pages_show_list,pages_read_engagement'; // Required permissions

// Facebook OAuth URLs
$oauthUrl = "https://www.facebook.com/v15.0/dialog/oauth?client_id=$appId&redirect_uri=$redirectUri&scope=$permissions";
$tokenUrl = "https://graph.facebook.com/v15.0/oauth/access_token";

if (!isset($_GET['code'])) {
    // Step 1: Redirect user to Facebook OAuth to get authorization code
    header("Location: $oauthUrl");
    exit;
} else {
    // Step 2: Exchange the 'code' for a user access token
    $code = $_GET['code'];

    $client = new Client();

    try {
        // Step 2a: Exchange code for user access token
        $response = $client->request('GET', $tokenUrl, [
            'query' => [
                'client_id' => $appId,
                'redirect_uri' => $redirectUri,
                'client_secret' => $appSecret,
                'code' => $code,
            ]
        ]);

        $body = json_decode($response->getBody(), true);

        if (isset($body['access_token'])) {
            $userAccessToken = $body['access_token'];
            echo "User Access Token: " . $userAccessToken . "\n";

            // Validate the token (optional, but good practice)
            $validateResponse = $client->request('GET', 'https://graph.facebook.com/debug_token', [
                'query' => [
                    'input_token' => $userAccessToken,
                    'access_token' => "$appId|$appSecret" // App access token format
                ]
            ]);

            $validateBody = json_decode($validateResponse->getBody(), true);

            if (!isset($validateBody['data']['is_valid']) || !$validateBody['data']['is_valid']) {
                throw new Exception('The access token is invalid or expired.');
            }

            // Step 3: Use the user access token to get the page access token
            $pageResponse = $client->request('GET', 'https://graph.facebook.com/v15.0/me/accounts', [
                'query' => [
                    'access_token' => $userAccessToken
                ]
            ]);

            $pageBody = json_decode($pageResponse->getBody(), true);

            if (isset($pageBody['data']) && count($pageBody['data']) > 0) {
                // Get the first page's access token
                $pageAccessToken = $pageBody['data'][0]['access_token'];
                $pageName = $pageBody['data'][0]['name'];
                echo "Page Access Token: " . $pageAccessToken . "\n";
                echo "Page Name: " . $pageName . "\n";

                // Step 4: Store the tokens in a text file
                $tokenFile = 'fb_tokens.txt';
                $content = "User Access Token: $userAccessToken\nPage Name: $pageName\nPage Access Token: $pageAccessToken\n";
                file_put_contents($tokenFile, $content);
                echo "Tokens saved in fb_tokens.txt\n";
            } else {
                echo "No pages found or no access to any pages.\n";
            }
        } else {
            echo "Error: User access token not found.\n";
        }
    } catch (GuzzleHttp\Exception\RequestException $e) {
        // Catch any request exceptions
        echo 'Request Error: ' . $e->getMessage();
    } catch (Exception $e) {
        // Catch any general exceptions
        echo 'Error: ' . $e->getMessage();
    }
}
