<?php

require_once 'constants.php';

require_once __DIR__ . '/vendor/autoload.php'; // Autoload the Guzzle HTTP client

use GuzzleHttp\Client;
use GuzzleHttp\Exception\RequestException;

// Replace with your app ID, app secret, and the short-lived token you obtained
$appId = APP_ID;
$appSecret = APP_SECRET;
$shortLivedAccessToken = SHORT_LIVED_ACCESS_TOKEN;

// Create a new Guzzle client
$client = new Client();

try {
    // Make the request to exchange the short-lived token for a long-lived token
    $response = $client->request('GET', GRAPH_API_URL, [
        'query' => [
            'grant_type' => 'fb_exchange_token',
            'client_id' => $appId,
            'client_secret' => $appSecret,
            'fb_exchange_token' => $shortLivedAccessToken,
        ]
    ]);

    // Get the response body and decode the JSON
    $data = json_decode($response->getBody(), true);

    // Extract the long-lived access token
    $longLivedAccessToken = $data['access_token'];

    echo "Long-Lived Access Token: " . $longLivedAccessToken . "\n";

    // Optionally, you can save this token for later use (in a database or file)
    file_put_contents('long_lived_token.txt', $longLivedAccessToken);

} catch (RequestException $e) {
    // Handle the request exception
    if ($e->hasResponse()) {
        $errorResponse = $e->getResponse()->getBody()->getContents();
        echo 'Error: ' . $errorResponse;
    } else {
        echo 'Request Error: ' . $e->getMessage();
    }
} catch (Exception $e) {
    // Handle any other exceptions
    echo 'General Error: ' . $e->getMessage();
}
